:orphan:



.. _sphx_glr_tutorials2:

Advanced Users Documents
========================

If you are familiar with event_model architecture data and databroker and you would like to process such data,
below are the documents for you.

The example data is packed in a python package ``dbexample``.
Install the package before you run the notebooks or scripts::

    python -m pip install dbexample




.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="This analyzer processes the x-ray powder diffraction images and yields pair distribution functi...">

.. only:: html

 .. figure:: /tutorials2/images/thumb/sphx_glr_plot_xpd_analyzer_thumb.png
     :alt: XPD Analyzer

     :ref:`sphx_glr_tutorials2_plot_xpd_analyzer.py`

.. raw:: html

    </div>


.. toctree::
   :hidden:

   /tutorials2/plot_xpd_analyzer
.. raw:: html

    <div class="sphx-glr-clear"></div>



.. only :: html

 .. container:: sphx-glr-footer
    :class: sphx-glr-footer-gallery


  .. container:: sphx-glr-download sphx-glr-download-python

    :download:`Download all examples in Python source code: tutorials2_python.zip </tutorials2/tutorials2_python.zip>`



  .. container:: sphx-glr-download sphx-glr-download-jupyter

    :download:`Download all examples in Jupyter notebooks: tutorials2_jupyter.zip </tutorials2/tutorials2_jupyter.zip>`


.. only:: html

 .. rst-class:: sphx-glr-signature

    `Gallery generated by Sphinx-Gallery <https://sphinx-gallery.github.io>`_
